# -*- coding: utf-8 -*-
"""
Created on Thu Jan 10 08:43:11 2019

@author: Staubach
"""

import numpy as np
import matplotlib.pyplot as plt
from matplotlib import cm
from matplotlib import gridspec


plt.rcParams['xtick.direction'] = 'in'
plt.rcParams['ytick.direction'] = 'in'
plt.rcParams['font.size'] = 10
plt.rcParams['text.usetex'] = True
plt.rcParams['text.color'] = 'black'
plt.rcParams['axes.spines.top'] = False
plt.rcParams['axes.spines.right'] = False
# -----------------------------------------------------------------------------
# Color definitions (RGB)
# -----------------------------------------------------------------------------
                        
# Color schemes generated with "internal" color maps          
start = 0.0
stop = 1.0
number_of_lines= 6

coolwarm = [ cm.coolwarm(x) for x in np.linspace(start, stop, number_of_lines)  ]


# -----------------------------------------------------------------------------
# Functions / Definitions
# -----------------------------------------------------------------------------
def cm2inch(*tupl):
    inch = 2.54
    if isinstance(tupl[0], tuple):
        return tuple(i/inch for i in tupl[0])
    else:
        return tuple(i/inch for i in tupl)

# -----------------------------------------------------------------------------
# Enter folder names
# -----------------------------------------------------------------------------
    
#folder_list = [ 'u8pp4','u3p3-sat-mini','u4u4-red','u4u4-red_explicit','u8u8-3D-red-explicit','u4p4-sat-mini','u8u8-3D-red']
folder_list = ['u8p4-sat', 'u8p4-sat-red', 'u8p4u8','u8p8u8','u4p4u4',\
               'u4u4','u8u8','u4u4-red','u4u4-red-explicit','u20p8u20','u20p8s','u20u20','u27p8s','u8u8-3D-red-explicit','u8u8-3D-red']
#'u4p4-sat-mini',
nfolders = len(folder_list)
output_folder = 'column-print-out'
output_folder2 = 'column-print-out'
# -----------------------------------------------------------------------------
# Analytical data
# -----------------------------------------------------------------------------
fname = 'analytical/output_Pw_v6_Para2.inp'
tmp = np.loadtxt(fname, skiprows=0 )
t1_ana = tmp[:,0] 
pw_ana = tmp[:,1] 

fname = 'analytical/output_Us.inp'
tmp = np.loadtxt(fname, skiprows=0 )
t2_ana = tmp[:,0] 
u2_ana = tmp[:,1]*1e3 


# -----------------------------------------------------------------------------
# Plotting ranges
# -----------------------------------------------------------------------------

xmax = 0.05
xmin = 0.0
ymax = 2.5

# Begin figure
fig = plt.figure(figsize=cm2inch(18,9*nfolders)) 

# Set the layout of the subplots
gs = gridspec.GridSpec(nfolders,2)

i = 0
for name in folder_list:
    if(name in ['u8u8','u20u20']):
        pw_numg = np.genfromtxt(name + '/'+ output_folder +'/' + 'BOTTOM_element_1.dat', delimiter=None, skip_header=1, skip_footer=0, usecols=-1)
        t_numg = np.genfromtxt(name + '/'+ output_folder +'/' + 'BOTTOM_element_1.dat', delimiter=None, skip_header=1, skip_footer=0, usecols=0) -1.0
    elif(name in ['u4u4','u4u4-red','u4u4-red-explicit']):
        try:
            pw_numg = np.genfromtxt(name + '/'+ output_folder +'/' + 'BOTTOM_element_40.dat', delimiter=None, skip_header=1, skip_footer=0, usecols=-1)
            t_numg = np.genfromtxt(name + '/'+ output_folder +'/' + 'BOTTOM_element_40.dat', delimiter=None, skip_header=1, skip_footer=0, usecols=0) -1.0
        except:
            pw_numg = np.genfromtxt(name + '/'+ output_folder2 +'/' + 'BOTTOM_element_40.dat', delimiter=None, skip_header=1, skip_footer=0, usecols=-1)
            t_numg = np.genfromtxt(name + '/'+ output_folder2 +'/' + 'BOTTOM_element_40.dat', delimiter=None, skip_header=1, skip_footer=0, usecols=0) -1.0
    elif(name in ['u8u8-3D-red-explicit','u8u8-3D-red']):
        try:
            pw_numg = np.genfromtxt(name + '/'+ output_folder +'/' + 'BOTTOM_element_1.dat', delimiter=None, skip_header=1, skip_footer=0, usecols=-1)
            t_numg = np.genfromtxt(name + '/'+ output_folder +'/' + 'BOTTOM_element_1.dat', delimiter=None, skip_header=1, skip_footer=0, usecols=0) -1.0
        except:
            pw_numg = np.genfromtxt(name + '/'+ output_folder2 +'/' + 'BOTTOM_element_1.dat', delimiter=None, skip_header=1, skip_footer=0, usecols=-1)
            t_numg = np.genfromtxt(name + '/'+ output_folder2 +'/' + 'BOTTOM_element_1.dat', delimiter=None, skip_header=1, skip_footer=0, usecols=0)
    elif(name in ['u20u20','u4p4u4']):
        t_numg = np.genfromtxt(name + '/'+ output_folder +'/'  + 'BOTTOM_NODE_node_82.dat', delimiter=None, skip_header=1, skip_footer=0, usecols=0) -1.0
        pw_numg = np.genfromtxt(name + '/'+ output_folder +'/'  + 'BOTTOM_NODE_node_82.dat', delimiter=None, skip_header=1, skip_footer=0, usecols=1)
    else:
        t_numg = np.genfromtxt(name + '/'+ output_folder +'/'  + 'BOTTOM_NODE_node_1.dat', delimiter=None, skip_header=1, skip_footer=0, usecols=0) -1.0
        pw_numg = np.genfromtxt(name + '/'+ output_folder +'/'  + 'BOTTOM_NODE_node_1.dat', delimiter=None, skip_header=1, skip_footer=0, usecols=1)
    pw_numg = pw_numg - pw_numg[0]
    
    if(name in ['u4u4','u4u4-red','u4p4u4','u4u4-red-explicit']):
        try:
            u2_numg = np.genfromtxt(name + '/'+ output_folder +'/'  + 'TOP_NODE_node_1.dat', delimiter=None, skip_header=1, skip_footer=0, usecols=2) * 1e3
        except:
            u2_numg = np.genfromtxt(name + '/'+ output_folder2 +'/'  + 'TOP_NODE_node_1.dat', delimiter=None, skip_header=1, skip_footer=0, usecols=2) * 1e3
    elif(name in ['u8u8-3D-red-explicit','u8u8-3D-red']):
        try:
            u2_numg = np.genfromtxt(name + '/'+ output_folder +'/'  + 'TOP_node_201.dat', delimiter=None, skip_header=3, skip_footer=0, usecols=3) * -1e3
        except:
            u2_numg = np.genfromtxt(name + '/'+ output_folder2 +'/'  + 'TOP_node_201.dat', delimiter=None, skip_header=3, skip_footer=0, usecols=3) * -1e3
    elif(name in ['u20p8u20','u20p8s','u20u20','u27p8s']):
        u2_numg = np.genfromtxt(name + '/'+ output_folder +'/'  + 'TOP_NODE_node_201.dat', delimiter=None, skip_header=1, skip_footer=0, usecols=3) * -1e3
    elif(name in ['u3p3-sat-mini','u4p4-sat-mini']):
        u2_numg = np.genfromtxt(name + '/'+ output_folder +'/'  + 'TOP_NODE_node_161.dat', delimiter=None, skip_header=1, skip_footer=0, usecols=2) * 1e3
    else:
        u2_numg = np.genfromtxt(name + '/'+ output_folder +'/'  + 'TOP_NODE_node_201.dat', delimiter=None, skip_header=1, skip_footer=0, usecols=2) * 1e3
    
    plt.subplot(gs[i])
    plt.title(name,fontsize=11)
    plt.plot(t1_ana,pw_ana, color='black', linestyle='--', lw=0.75, label='Analytical')
    plt.plot(t_numg,pw_numg, color=coolwarm[1], lw=0.75, label='numgeo')
    plt.xlim(0,xmax)
    plt.ylim(-2,22)
    plt.ylabel('Excess pore-water pressure $\Delta p_w$ [kPa]' )
    plt.xlabel('Time t [s]')
    #plt.legend(bbox_to_anchor=(0.4,0.6))
    #plt.legend()
    #plt.grid(True)
    
    plt.subplot(gs[i+1])
    plt.title(name,fontsize=11)
    plt.plot(t2_ana,u2_ana, color='black', linestyle='--', lw=0.75, label='Analytical')
    plt.plot(t_numg,u2_numg, color=coolwarm[1], lw=0.75, label='numgeo')
    plt.xlim(0,xmax)
    plt.ylim(-0.5,0)
    plt.ylabel('Vertical displacement $u_2$ [$10^{-3}$ m]' )
    plt.xlabel('Time t [s]')
    plt.legend(loc='lower left')
    #plt.grid(True)
    
    i = i + 2

plt.tight_layout(w_pad=1.5)
plt.show()

fig.savefig('column_heavyside_load_ke-3_f30.pdf', bbox_inches='tight')
fig.savefig('column_heavyside_load_ke-3_f30.png', dpi=800, bbox_inches='tight')
#fig.savefig('column_heavyside_load_ke-3_f30.svg', bbox_inches='tight')